@@ -1,7 +1,7 @@
 /* DXFExportSub.m
  * subclass of DXFExport
  *
- * Copyright (C) 2002-2015 by Cenon GmbH
+ * Copyright (C) 2002-2016 by Cenon GmbH
  * Author:   Ilonka Fleischmann
  *
  * created:  2002-04-25
@@ -38,7 +38,7 @@
 #include <AppKit/AppKit.h>
 #include <VHFShared/vhfCommonFunctions.h>
 #include <VHFShared/VHFStringAdditions.h>   // stringByReplacing -> eps export
-#include <VHFShared/vhfSystemAdditions.h>   // [NSFileManager methods]
+#include <VHFShared/VHFSystemAdditions.h>   // [NSFileManager methods]
 #include "App.h"
 #include "DXFExportSub.h"
 #include "Graphics.h"
