@@ -943,7 +943,7 @@ static NSMutableArray *zoneList = nil;
 #ifdef __APPLE__    // well, he! the are lazy developers at Apple, the above works two times then never again
         [window setTitle:name];
 #endif
-        NSSetZoneName((NSZone*)[self zone], fileName);
+        //NSSetZoneName((NSZone*)[self zone], fileName);
     }
 }
 
