@@ -1,11 +1,12 @@
 /* VTextPath.m
  * 2-D Textpath - text written on path
  *
- * Copyright (C) 2000-2014 by Cenon GmbH
+ * Copyright (C) 2000-2016 by Cenon GmbH
  * Author:   Georg Fleischmann
  *
  * created:  2000-07-31
- * modified: 2014-09-02 (-getFlattenedObjectAt:.. set direction of text to group object)
+ * modified: 2016-10-20 (-setFontSize:, -fontSize: float -> VFloat)
+ *           2014-09-02 (-getFlattenedObjectAt:.. set direction of text to group object)
  *           2011-05-30 (-label, -setLabel: forwarded to path object)
  *
  * This program is free software; you can redistribute it and/or
@@ -115,11 +116,11 @@
 - (void)incrementSerialNumberBy:(int)o	{ [text incrementSerialNumberBy:o]; dirty = YES; }
 
 
-- (void)setFontSize:(float)v	{ [text setFontSize:v]; dirty = YES; }
-- (float)fontSize		{ return [text fontSize]; }
+- (void)setFontSize:(VFloat)v   { [text setFontSize:v]; dirty = YES; }
+- (VFloat)fontSize              { return [text fontSize]; }
 
 - (void)setColor:(NSColor*)col	{ [text setColor:col]; }
-- (NSColor*)color		{ return [text color]; }
+- (NSColor*)color               { return [text color]; }
 
 - (NSColor*)fillColor			{ return [text fillColor]; }
 - (void)setFillColor:(NSColor*)col;	{ [text setFillColor:col]; }
@@ -279,10 +280,10 @@
 
         //x = [text characterOffsetAtIndex:i];
         x = rect.origin.x;
-        p = [path pointAt:x/length];
+        p = [path pointAt:((length > 0.0) ? x/length : 0.0)];
         charText = [text subTextWithRange:NSMakeRange(i, 1)];
         [charText moveTo:NSMakePoint(p.x, p.y+[[charText font] descender])];
-        g = [path gradientAt:(x+rect.size.width/2.0)/length];
+        g = [path gradientAt:((length > 0.0) ? (x+rect.size.width/2.0)/length : 0.0)];
         angle = (Diff(g.x/2.0, 0.0)<TOLERANCE) ? 90.0 : Atan(g.y/g.x);
         if ( (g.x<0.0 && g.y>0.0) || (g.x<0.0 && g.y<0.0) )	// 2nd, and 3rd quadrant
             angle += 180.0;
@@ -303,14 +304,14 @@
  */
 - (NSRect)coordBounds
 {   NSRect	bRect = [path coordBounds];
-    float	h = [text lineHeight];
+    VFloat	h = [text lineHeight];
 
     bRect = NSInsetRect(bRect, -h, -h);
     return bRect;
 }
 - (NSRect)bounds
 {   NSRect	bRect = [path bounds];
-    float	h = [text lineHeight];
+    VFloat	h = [text lineHeight];
 
     bRect = NSInsetRect(bRect, -h, -h);
     return bRect;
