@@ -1,36 +1,37 @@
 /* IPAllLayers.h
  * Layer management Inspector for all objects
  *
- * Copyright (C) 2002 by vhf interservice GmbH
+ * Copyright (C) 2002-2014 by Cenon GmbH
  * Author:   Ilonka Fleischmann, Georg Fleischmann
  *
  * created:  2002-06-27
- * modified: 2002-10-05
+ * modified: 2005-08-31
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the vhf Public License as
- * published by vhf interservice GmbH. Among other things, the
+ * modify it under the terms of the Cenon Public License as
+ * published by Cenon GmbH. Among other things, the
  * License requires that the copyright notices and this notice
  * be preserved on all copies.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * See the vhf Public License for more details.
+ * See the Cenon Public License for more details.
  *
- * You should have received a copy of the vhf Public License along
- * with this program; see the file LICENSE. If not, write to vhf.
+ * You should have received a copy of the Cenon Public License along
+ * with this program; see the file LICENSE. If not, write to Cenon.
  *
- * vhf interservice GmbH, Im Marxle 3, 72119 Altingen, Germany
- * eMail: info@vhf.de
- * http://www.vhf.de
+ * Cenon GmbH, Schwabstr. 45, 72108 Rottenburg a.N., Germany
+ * eMail: info@Cenon.com
+ * http://www.Cenon.de
  */
 
-#ifndef VHF_H_IPALLLAYERS
-#define VHF_H_IPALLLAYERS
+#ifndef CEN_H_IPALLLAYERS
+#define CEN_H_IPALLLAYERS
 
 #include <AppKit/AppKit.h>
 #include "IPBasicLevel.h"
+#include "../LayerObject.h"
 
 @interface IPAllLayers:IPBasicLevel
 {
@@ -43,6 +44,7 @@
 }
 
 - init;
+- (LayerObject*)currentLayerObject;
 - (void)update:sender;
 
 - (void)setName:sender;
@@ -57,4 +59,4 @@
 
 @end
 
-#endif // VHF_H_IPALLLAYERS
+#endif // CEN_H_IPALLLAYERS
