@@ -1,11 +1,12 @@
 /* DXFImport.m
  * DXF import object
  *
- * Copyright (C) 1996-2015 by Cenon GmbH
+ * Copyright (C) 1996-2016 by Cenon GmbH
  * Author:   Georg Fleischmann
  *
  * created:  1996-05-01
- * modified: 2015-06-19 (-getText: remove formatting codes from string, log added
+ * modified: 2016-08-04 (-getPolyline: TODOs added for group.flags, -getVertex: ignore group.flag == 4 (SPLINE frame control point))
+ *           2015-06-19 (-getText: remove formatting codes from string, log added
  *           2014-08-29 (-getArc:::: if group.ext transform the complete arc)
  *           2014-08-29 (-scanGroup: group.color no init)
  *           2014-07-04 (-getText: fontName added to internal declaration)
@@ -228,7 +229,7 @@ static BOOL gotoTable(NSScanner *scanner, NSString *name)
 }
 
 /* created:   1993-05-17
- * modified:  2001-02-23
+ * modified:  2013-04-16 (font name)
  *
  * purpose:   get tables from data
  *            at the moment we only read the layer table...
@@ -1049,8 +1050,8 @@ static NSColor *getColorFromLayer(NSString *str, NSArray *layers)
     return YES;
 }
 
-/* created:   18.05.93
- * modified:  10.06.93 30.09.94 01.05.96
+/* created:   1993-05-18
+ * modified:  2016-08-04 (group.flags: TODOs added)
  *
  * purpose:   get polyline
  * parameter: scanner (the dxf data at id line)
@@ -1072,7 +1073,23 @@ static NSColor *getColorFromLayer(NSString *str, NSArray *layers)
     state.endWidth = (group.endWidth<0) ? 0 : DeviceResToInternal(group.endWidth, res);
 
     state.mode = (group.more == 1) ? MODE_VERTEX : 0;
-    state.modeClosed = ( group.flags ==  1 ) ? MODE_CLOSED : 0;
+
+    /* group.flags (70) */
+    state.modeClosed = ( group.flags & 1 ) ? MODE_CLOSED : 0;   // 70 = 1 = closed polyline
+    if ( group.flags &   2 )                                    // TODO: Curve fit vertices added
+        printf("TODO, DXF-Import: POLYLINE: Curve fits not supported\n");
+    if ( group.flags &   4 )                                    // TODO: SPLINE fit vertices added (see example: "POLYLINE_with_SPLINE/T35GIT.dxf")
+        printf("TODO, DXF-Import: POLYLINE: SPLINE fits not supported\n");
+    if ( group.flags &   8 )                                    // TODO: 3D polyline
+        printf("TODO, DXF-Import: POLYLINE: 3D polyline not supported\n");
+    if ( group.flags &  16 )                                    // TODO: 3D polygon mesh
+        printf("TODO, DXF-Import: POLYLINE: 3D polymesh not supported\n");
+    if ( group.flags &  32 )                                    // TODO: polygon mesh is closed
+        ;
+    if ( group.flags &  64 )                                    // TODO: polyline is a polyface mesh
+        ;
+    if ( group.flags & 128 )                                    // TODO: continuous line type pattern
+        printf("TODO, DXF-Import: POLYLINE: line type not supported\n");
 
     state.id = 0;
 
@@ -1080,7 +1097,7 @@ static NSColor *getColorFromLayer(NSString *str, NSArray *layers)
 }
 
 /* created:   1993-05-18
- * modified:  1998-08-05
+ * modified:  2016-08-04 (group.flags = 16 = SPLINE frame control point ignored)
  *
  * purpose:   get vertex
  * parameter: cp (the dxf data)
@@ -1094,6 +1111,22 @@ static NSColor *getColorFromLayer(NSString *str, NSArray *layers)
     a = group.a;	// type is one behind
     [self scanGroup:scanner];
 
+    /* group.flags (70) */
+    //if ( group.flags &   1 )  // TODO: Curve fitting
+    //    printf("TODO, DXF-Import: VERTEX: Curve fitting not supported\n");
+    //if ( group.flags &   2 )  // TODO: Curve fit tangent defined for this vertex
+    //    printf("TODO, DXF-Import: VERTEX: Curve fit tangent not supported\n");
+    //if ( group.flags &   8 )  // TODO: SPLINE vertex
+    //    printf("TODO, DXF-Import: VERTEX: SPLINE vertex not supported\n");
+    if ( group.flags &  16 )  // TODO: SPLINE frame control point
+        return NO;
+    //if ( group.flags &  32 )  // TODO: 3D polyline vertex
+    //    printf("TODO, DXF-Import: VERTEX: 3D polyline vertex not supported\n");
+    //if ( group.flags &  64 )  // TODO: 3D polygon mesh
+    //    printf("TODO, DXF-Import: VERTEX: 3D polygon mesh not supported\n");
+    //if ( group.flags & 128 )  // TODO: polyface mesh vertex
+    //    printf("TODO, DXF-Import: VERTEX: polyface mesh vertex not supported\n");
+
     state.color = [self currentColor];
     /* get element specific begin width */
     bw = (group.width<0)    ? state.begWidth : DeviceResToInternal(group.width, res);
@@ -1388,7 +1421,8 @@ static void buildArc(NSPoint beg, NSPoint end, double a, NSPoint *ctr, float *an
 }
 
 /* created:   1993-06-11
- * modified:  2015-06-19 (text formatting: remove formatting codes, log added)
+ * modified:  2016-04-20 (get fontName from formatting codes)
+ *            2015-06-19 (text formatting: remove formatting codes, log added)
  *            2013-04-16 (fontName added)
  *
  * purpose:   get text (TEXT, MTEXT)
@@ -1420,6 +1454,22 @@ static void buildArc(NSPoint beg, NSPoint end, double a, NSPoint *ctr, float *an
     if (![group.text length])
         return NO;
 
+    if ( ! group.style )
+        group.style = @"Standard";  // FIXME: this should be case insensitive
+    if ( [table objectForKey:@"style"] )
+    {   NSDictionary    *styles = [table objectForKey:@"style"];
+        NSDictionary    *style = [styles objectForKey:group.style];
+
+        if ( [style objectForKey:@"fontName"] )
+            *fontName = [style objectForKey:@"fontName"];
+        else if ( [style objectForKey:@"fileName"] )
+        {   NSString    *fn = [style objectForKey:@"fileName"];
+
+            NSLog(@"DXF-Import, MTEXT: unknown font file: \"%@\". Using Default.", fn);
+            *fontName = nil;
+        }
+    }
+
     state.color = [self currentColor];
     textHeight = *size = DeviceResToInternal(group.width, res) * 3.0/2.0;
     *string = [[group.text stringByReplacing:@"\\P" by:@"\n"] retain];	// convert newline
@@ -1456,7 +1506,7 @@ static void buildArc(NSPoint beg, NSPoint end, double a, NSPoint *ctr, float *an
                 case 'A':
                 case 'c':   // \C1;     color change
                 case 'C':
-                case 'f':   // \F...;   font selection
+                case 'f':   // \F...;   font selection (\fG1L S04 Futura|b0|i0|c0|p2;)
                 case 'F':
                 case 'h':   // \H3x;    text height
                 case 'H':
@@ -1469,7 +1519,21 @@ static void buildArc(NSPoint beg, NSPoint end, double a, NSPoint *ctr, float *an
                     range1 = [mString rangeOfString:@";" options:0 range:searchRange];   // "\...;"
                     if ( range1.length )
                     {   range.length = range1.location+1;
-                        // TODO: interpret into attributed string
+                        switch ( uchar )
+                        {
+                            case 'f':   // \F...;   font selection (\fG1L S04 Futura|b0|i0|c0|p2;)
+                            case 'F':
+                            {   NSRange     range2 = [mString rangeOfString:@"|" options:0 range:searchRange];
+                                NSString    *fn = [mString substringWithRange:NSMakeRange(range.location+2, range2.location-range.location-2)];
+                                //[NSFont fontWithName:fn size:textHeight]; // test, if font is available (needs App Kit)
+                                *fontName = [fn retain];
+                                // TODO: bold, italic, code page (color), pitch "b0|i0|c0|p2"
+                                break;
+                            }
+                            // TODO: interpret into attributed string
+                            default:
+                                NSLog(@"DXF-Import, MTEXT: formatting code '%c' not implemented yet: \"%@\"", uchar, mString);
+                        }
                         [mString replaceCharactersInRange:range withString:@""];
                     }
                     else
@@ -1504,7 +1568,7 @@ static void buildArc(NSPoint beg, NSPoint end, double a, NSPoint *ctr, float *an
             }
         }
 
-        NSLog(@"DXF-Import, MTEXT: text formatting ignored: \"%@\"", *string);
+        NSLog(@"DXF-Import, MTEXT: text formatting (mostly) ignored: \"%@\"", *string);
         [*string release];
         *string = mString;
     }
@@ -1517,21 +1581,6 @@ static void buildArc(NSPoint beg, NSPoint end, double a, NSPoint *ctr, float *an
     adjust = group.adjust;	// get adjust position from file
     adjustPoint.x = DeviceResToInternal(group.x1, res);
     adjustPoint.y = DeviceResToInternal(group.y1, res);
-    if ( ! group.style )
-        group.style = @"Standard";  // FIXME: this should be case insensitive
-    if ( [table objectForKey:@"style"] )
-    {   NSDictionary    *styles = [table objectForKey:@"style"];
-        NSDictionary    *style = [styles objectForKey:group.style];
-
-        if ( [style objectForKey:@"fontName"] )
-            *fontName = [style objectForKey:@"fontName"];
-        else if ( [style objectForKey:@"fileName"] )
-        {   NSString    *fn = [style objectForKey:@"fileName"];
-
-            NSLog(@"DXF-Import, MTEXT: unknown font file: \"%@\". Using Default.", fn);
-            *fontName = nil;
-        }
-    }
 
     if (!mtext)
     {
