@@ -1,11 +1,12 @@
 /* dvPasteboard.m
  * Pasteboard additions for Cenon DocView class
  *
- * Copyright (C) 1997-2014 by Cenon GmbH
+ * Copyright (C) 1997-2016 by Cenon GmbH
  * Author:   Georg Fleischmann
  *
  * created:  1997
- * modified: 2008-10-21 (pasting of several layers to one layer keeps order of graphics elements)
+ * modified: 2016-02-26 (originalPast: retain/release)
+ *           2008-10-21 (pasting of several layers to one layer keeps order of graphics elements)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the Cenon Public License as
@@ -50,11 +51,11 @@ NSString *e2MatchTypes(NSArray *typesToMatch, NSArray *orderedTypes)
     int index = 0;
 
     while (index < typesCount)
-    {   NSString * currType = [orderedTypes objectAtIndex:index];
+    {   NSString *currType = [orderedTypes objectAtIndex:index];
 
-	if (e2IncludesType(typesToMatch, currType))
-	    return currType;
-	++index;
+        if (e2IncludesType(typesToMatch, currType))
+            return currType;
+        ++index;
     }
     return nil;
 }
@@ -65,8 +66,8 @@ NSString *e2MatchTypes(NSArray *typesToMatch, NSArray *orderedTypes)
  */
 NSString *e2TextPasteType(NSArray *types)
 {
-    if (e2IncludesType(types, NSRTFPboardType)) return NSRTFPboardType;
-    if (e2IncludesType(types, NSStringPboardType)) return NSStringPboardType;
+    if (e2IncludesType(types, NSRTFPboardType))     return NSRTFPboardType;
+    if (e2IncludesType(types, NSStringPboardType))  return NSStringPboardType;
     return nil;
 }
 
@@ -128,12 +129,12 @@ NSArray *e2TypesCenonExports(void)
  * to perform this very function).
  */
 + (void)convert:(NSUnarchiver *)unarchiver to:(NSString *)type using:(SEL)writer toPasteboard:(NSPasteboard *)pb
-{   NSWindow		*w;
-    NSMutableArray	*array;
-    NSData		*data;
-    DocView		*scrapper;
-    NSRect		scrapperFrame = {{0.0, 0.0}, {11.0*72.0, 14.0*72.0}};
-    static NSZone	*scrapperZone = NULL;
+{   NSWindow        *w;
+    NSMutableArray  *array;
+    NSData          *data;
+    DocView         *scrapper;
+    NSRect          scrapperFrame = {{0.0, 0.0}, {11.0*72.0, 14.0*72.0}};
+    static NSZone   *scrapperZone = NULL;
 
     if (!scrapperZone)
         scrapperZone = NSCreateZone(NSPageSize(), NSPageSize(), YES);
@@ -329,10 +330,10 @@ NSArray *e2TypesCenonExports(void)
 
     if ([slayList count] > 0)
     {
-	change = [[CutGraphicsChange alloc] initGraphicView:self];
-	[change startChange];
+        change = [[CutGraphicsChange alloc] initGraphicView:self];
+        [change startChange];
             [self copy:sender];
-//        lastCutChangeCount = lastCopiedChangeCount;
+            //lastCutChangeCount = lastCopiedChangeCount;
             [self delete:sender];
             consecutivePastes = 0;
         [change endChange];
@@ -352,7 +353,8 @@ NSArray *e2TypesCenonExports(void)
         {   NSMutableArray	*list = [slayList objectAtIndex:l];
 
             if (list && [list count])
-            {	originalPaste = [list objectAtIndex:0];
+            {   [originalPaste release];
+                originalPaste = [[list objectAtIndex:0] retain];
                 break;
             }
         }
@@ -576,14 +578,14 @@ NSArray *e2TypesCenonExports(void)
  * first and second pastes (this is also known as "transform again").
  */
 - (void)paste:sender andLink:(LinkType)doLink
-{   NSArray		*pblist;
-    NSPoint		offset;
+{   NSArray         *pblist;
+    NSPoint         offset;
     VGraphic		*graphic = nil;
     NSPasteboard	*pboard = [NSPasteboard generalPasteboard];
-    NSRect		originalBounds, secondBounds, rect, bounds;
+    NSRect          originalBounds, secondBounds, rect, bounds;
     static VGraphic	*secondPaste;
     static NSPoint	pasteOffset;
-    int			l;
+    int             l;
 
     /* FIXME: We shouldn't insert the pblist in this method.
      * Instead we should return pblist and insert it here
@@ -610,7 +612,8 @@ NSArray *e2TypesCenonExports(void)
 
             consecutivePastes = 0;
             lastPastedChangeCount = [pboard changeCount];
-            originalPaste = graphic;
+            [originalPaste release];
+            originalPaste = [graphic retain];
 
             /* keep graphics inside visible rect for 1st paste */
             pbBounds = [self boundsOfArray:slayList withKnobs:NO];
@@ -652,7 +655,7 @@ NSArray *e2TypesCenonExports(void)
             }
             else if ((consecutivePastes == 2) && graphic)
             {
-                originalBounds = [originalPaste bounds];
+                originalBounds = [originalPaste bounds];    // FIXME: crash possible if object has been deleted from uncontrolled environment
                 secondBounds = [secondPaste bounds];
                 pasteOffset.x = secondBounds.origin.x - originalBounds.origin.x;
                 pasteOffset.y = secondBounds.origin.y - originalBounds.origin.y;
@@ -670,9 +673,9 @@ NSArray *e2TypesCenonExports(void)
 
             /* move selected objects */
             for (l=[slayList count]-1; l>=0; l--)
-            {	NSMutableArray	*slist = [slayList objectAtIndex:l];
-                LayerObject	*layer = [layerList objectAtIndex:l];
-                int		i;
+            {	NSMutableArray  *slist = [slayList objectAtIndex:l];
+                LayerObject     *layer = [layerList objectAtIndex:l];
+                int             i;
 
                 for (i=[slist count]-1; i>=0; i--)
                 {   VGraphic	*g = [slist objectAtIndex:i];
